@@ -25,7 +25,7 @@ class DeviceAuthHandler:
 
         response2 = requests.request("POST", url2, data=payload2, headers=headers2, params=querystring2)
 
-        return response2.json
+        return response2.json()
 
     def deviceCodeData(self, deviceCode):
         clientToken = "NTIyOWRjZDNhYzM4NDUyMDhiNDk2NjQ5MDkyZjI1MWI6ZTNiZDJkM2UtYmY4Yy00ODU3LTllN2QtZjNkOTQ3ZDIyMGM3"
@@ -40,7 +40,7 @@ class DeviceAuthHandler:
 
         response3 = requests.request("POST", url3, data=payload3, headers=headers3)
 
-        return response3.json
+        return response3.json()
 
     def getDeviceAuthDetails(self,account_id):
         url = f"https://account-public-service-prod.ol.epicgames.com/account/api/public/account/{account_id}/deviceAuth"
@@ -52,7 +52,7 @@ class DeviceAuthHandler:
 
         response = requests.request("POST", url, headers=headers)
 
-        return response.json
+        return response.json()
 
 def getDisplayName(account_id, access_token):
 
